import os, time
def version_declaration():
    """
    The module is about library`s version
    And the author is HuiBuBu(LanBuBu)
    """
    print("""
lison_technology[v0.0.1]-->The program is stable
    """)

class out:
    def motion(self, frames, second):
        """
        Achieve dynamic effects
        """
        second / frames
        print(self)
        time.sleep(round(second, 2))
        os.system("cls")
